
From: Adrian Bunk <bunk@stusta.de>

The patch below makes the following changes to 
drivers/parport/parport_pc.c :
- make some needlessly global functions static
- #if 0 two currently unused functions

Signed-off-by: Adrian Bunk <bunk@stusta.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 /dev/null                            |    0 
 25-akpm/drivers/parport/parport_pc.c |   30 +++++++++++++++++-------------
 25-akpm/include/linux/parport_pc.h   |    6 ------
 3 files changed, 17 insertions(+), 19 deletions(-)

diff -puN drivers/parport/parport_pc.c~some-parport_pcc-cleanups-fwd drivers/parport/parport_pc.c
--- 25/drivers/parport/parport_pc.c~some-parport_pcc-cleanups-fwd	Thu Dec  9 13:37:24 2004
+++ 25-akpm/drivers/parport/parport_pc.c	Thu Dec  9 13:37:24 2004
@@ -193,6 +193,7 @@ static int change_mode(struct parport *p
 
 #ifdef CONFIG_PARPORT_1284
 /* Find FIFO lossage; FIFO is reset */
+#if 0
 static int get_fifo_residue (struct parport *p)
 {
 	int residue;
@@ -233,6 +234,7 @@ static int get_fifo_residue (struct parp
 	DPRINTK (KERN_DEBUG "*** get_fifo_residue: done residue collecting (ecr = 0x%2.2x)\n", inb (ECONTROL (p)));
 	return residue;
 }
+#endif  /*  0 */
 #endif /* IEEE 1284 support */
 #endif /* FIFO support */
 
@@ -273,7 +275,7 @@ static irqreturn_t parport_pc_interrupt(
 	return IRQ_HANDLED;
 }
 
-void parport_pc_init_state(struct pardevice *dev, struct parport_state *s)
+static void parport_pc_init_state(struct pardevice *dev, struct parport_state *s)
 {
 	s->u.pc.ctr = 0xc;
 	if (dev->irq_func &&
@@ -285,7 +287,7 @@ void parport_pc_init_state(struct pardev
 			     * D.Gruszka VScom */
 }
 
-void parport_pc_save_state(struct parport *p, struct parport_state *s)
+static void parport_pc_save_state(struct parport *p, struct parport_state *s)
 {
 	const struct parport_pc_private *priv = p->physport->private_data;
 	s->u.pc.ctr = priv->ctr;
@@ -293,7 +295,7 @@ void parport_pc_save_state(struct parpor
 		s->u.pc.ecr = inb (ECONTROL (p));
 }
 
-void parport_pc_restore_state(struct parport *p, struct parport_state *s)
+static void parport_pc_restore_state(struct parport *p, struct parport_state *s)
 {
 	struct parport_pc_private *priv = p->physport->private_data;
 	register unsigned char c = s->u.pc.ctr & priv->ctr_writable;
@@ -732,9 +734,9 @@ dump_parport_state ("leave fifo_write_bl
 }
 
 /* Parallel Port FIFO mode (ECP chipsets) */
-size_t parport_pc_compat_write_block_pio (struct parport *port,
-					  const void *buf, size_t length,
-					  int flags)
+static size_t parport_pc_compat_write_block_pio (struct parport *port,
+						 const void *buf, size_t length,
+						 int flags)
 {
 	size_t written;
 	int r;
@@ -809,9 +811,9 @@ size_t parport_pc_compat_write_block_pio
 
 /* ECP */
 #ifdef CONFIG_PARPORT_1284
-size_t parport_pc_ecp_write_block_pio (struct parport *port,
-				       const void *buf, size_t length,
-				       int flags)
+static size_t parport_pc_ecp_write_block_pio (struct parport *port,
+					      const void *buf, size_t length,
+					      int flags)
 {
 	size_t written;
 	int r;
@@ -924,8 +926,10 @@ size_t parport_pc_ecp_write_block_pio (s
 	return written;
 }
 
-size_t parport_pc_ecp_read_block_pio (struct parport *port,
-				      void *buf, size_t length, int flags)
+#if 0
+static size_t parport_pc_ecp_read_block_pio (struct parport *port,
+					     void *buf, size_t length,
+					     int flags)
 {
 	size_t left = length;
 	size_t fifofull;
@@ -1143,7 +1147,7 @@ out_no_data:
 dump_parport_state ("fwd idle", port);
 	return length - left;
 }
-
+#endif  /*  0  */
 #endif /* IEEE 1284 support */
 #endif /* Allowed to use FIFO/DMA */
 
@@ -1156,7 +1160,7 @@ dump_parport_state ("fwd idle", port);
 
 /* GCC is not inlining extern inline function later overwriten to non-inline,
    so we use outlined_ variants here.  */
-struct parport_operations parport_pc_ops = 
+static struct parport_operations parport_pc_ops =
 {
 	.write_data	= parport_pc_write_data,
 	.read_data	= parport_pc_read_data,
diff -L drivers/parport/parport_pc.c.old -puN /dev/null /dev/null
diff -puN include/linux/parport_pc.h~some-parport_pcc-cleanups-fwd include/linux/parport_pc.h
--- 25/include/linux/parport_pc.h~some-parport_pcc-cleanups-fwd	Thu Dec  9 13:37:24 2004
+++ 25-akpm/include/linux/parport_pc.h	Thu Dec  9 13:37:24 2004
@@ -228,12 +228,6 @@ extern void parport_pc_release_resources
 
 extern int parport_pc_claim_resources(struct parport *p);
 
-extern void parport_pc_init_state(struct pardevice *, struct parport_state *s);
-
-extern void parport_pc_save_state(struct parport *p, struct parport_state *s);
-
-extern void parport_pc_restore_state(struct parport *p, struct parport_state *s);
-
 /* PCMCIA code will want to get us to look at a port.  Provide a mechanism. */
 extern struct parport *parport_pc_probe_port (unsigned long base,
 					      unsigned long base_hi,
diff -L include/linux/parport_pc.h.old -puN /dev/null /dev/null
_
